@@ -23,6 +23,7 @@ $EXEC ${test_dir}/grib_check_param_concepts paramId $ECCODES_DEFINITION_PATH/gri
 $EXEC ${test_dir}/grib_check_param_concepts paramId $ECCODES_DEFINITION_PATH/grib2/localConcepts/hydro/paramId.def
 $EXEC ${test_dir}/grib_check_param_concepts paramId $ECCODES_DEFINITION_PATH/grib2/localConcepts/tigge/paramId.def
 $EXEC ${test_dir}/grib_check_param_concepts paramId $ECCODES_DEFINITION_PATH/grib2/localConcepts/s2s/paramId.def
+$EXEC ${test_dir}/grib_check_param_concepts paramId $ECCODES_DEFINITION_PATH/grib2/localConcepts/era6/paramId.def
 
 $EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/grib2/shortName.def
 $EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/grib2/localConcepts/ecmf/shortName.def
@@ -30,6 +31,7 @@ $EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/g
 $EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/grib2/localConcepts/hydro/shortName.def
 $EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/grib2/localConcepts/tigge/shortName.def
 $EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/grib2/localConcepts/s2s/shortName.def
+$EXEC ${test_dir}/grib_check_param_concepts shortName $ECCODES_DEFINITION_PATH/grib2/localConcepts/era6/shortName.def
 
 # Check the group: name.def paramId.def shortName.def units.def cfVarName.def
 # ----------------------------------------------------------------------------
@@ -78,6 +80,25 @@ done
 
 cd $test_dir
 
+# -------------------------------
+echo "WMO legacy parameters..."
+# -------------------------------
+ECMF_DIR=$ECCODES_DEFINITION_PATH/grib2
+
+tempDir=temp.${label}.dir
+rm -fr $tempDir
+mkdir -p $tempDir
+cd $tempDir
+#cp $ECMF_DIR/cfName.legacy.def    cfName.def
+#cp $ECMF_DIR/cfVarName.legacy.def cfVarName.def
+cp $ECMF_DIR/name.legacy.def      name.def
+cp $ECMF_DIR/paramId.legacy.def   paramId.def
+cp $ECMF_DIR/shortName.legacy.def shortName.def
+cp $ECMF_DIR/units.legacy.def     units.def
+$CHECK_DEFS
+cd $test_dir
+rm -fr $tempDir
+
 # -------------------------------
 echo "ECMWF legacy parameters..."
 # -------------------------------
@@ -94,6 +115,26 @@ cp $ECMF_DIR/paramId.legacy.def   paramId.def
 cp $ECMF_DIR/shortName.legacy.def shortName.def
 cp $ECMF_DIR/units.legacy.def     units.def
 $CHECK_DEFS
+cd $test_dir
+rm -fr $tempDir
+
+# -------------------------------
+echo "Check duplicates"
+# -------------------------------
+paramIdFile=$ECCODES_DEFINITION_PATH/grib2/paramId.def
+pids=$(grep "^'" $paramIdFile | awk -F"'" '{printf "%s\n", $2}')
+set +e
+for p in $pids; do
+    # For each paramId found in the top-level WMO file, check if it also exists
+    # in the ECMWF local one
+    grep "'$p'"  $ECCODES_DEFINITION_PATH/grib2/localConcepts/ecmf/paramId.def
+    if [ $? -ne 1 ]; then
+      echo "ERROR: check paramId $p. Is it duplicated?"
+      exit 1
+    fi
+done
+set -e
+
 
 cd $test_dir
 rm -fr $tempDir
